/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.account.services;

import org.springframework.transaction.annotation.Transactional;

import java.util.Collection;

/**
 * Service for searching and storing "externStructurePersonDn"s.
 * <p/>
 * User: david
 * Date: 31/5-11
 * Time: 16:51
 */
public interface StructureService {

    /**
     * Search by query.
     *
     * @param query query
     * @return An "externStructurePersonDn" from the given query.
     */
    Collection<String> search(String query);

    /**
     * Stores the given "externStructurePersonDn".
     *
     * @param externStructurePersonDn externStructurePersonDn
     */
    @Transactional
    void storeExternStructurePersonDn(String externStructurePersonDn);

    /**
     * Sets the maximum number of search results that the <code>search(java.lang.String)</code> method.
     *
     * @param maxResults Maximum number of results
     */
    void setMaxResults(int maxResults);
}
